# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class AbiInput(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "name",
            "type",
        }
        
        class properties:
            name = schemas.StrSchema
            type = schemas.StrSchema
            indexed = schemas.BoolSchema
            
            
            class components(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['AbiInput']:
                        return AbiInput
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['AbiInput'], typing.List['AbiInput']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'components':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'AbiInput':
                    return super().__getitem__(i)
            internalType = schemas.StrSchema
            __annotations__ = {
                "name": name,
                "type": type,
                "indexed": indexed,
                "components": components,
                "internalType": internalType,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    name: MetaOapg.properties.name
    type: MetaOapg.properties.type
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["indexed"]) -> MetaOapg.properties.indexed: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["components"]) -> MetaOapg.properties.components: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["internalType"]) -> MetaOapg.properties.internalType: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["name"], typing_extensions.Literal["type"], typing_extensions.Literal["indexed"], typing_extensions.Literal["components"], typing_extensions.Literal["internalType"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["indexed"]) -> typing.Union[MetaOapg.properties.indexed, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["components"]) -> typing.Union[MetaOapg.properties.components, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["internalType"]) -> typing.Union[MetaOapg.properties.internalType, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["name"], typing_extensions.Literal["type"], typing_extensions.Literal["indexed"], typing_extensions.Literal["components"], typing_extensions.Literal["internalType"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        indexed: typing.Union[MetaOapg.properties.indexed, bool, schemas.Unset] = schemas.unset,
        components: typing.Union[MetaOapg.properties.components, list, tuple, schemas.Unset] = schemas.unset,
        internalType: typing.Union[MetaOapg.properties.internalType, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'AbiInput':
        return super().__new__(
            cls,
            *_args,
            name=name,
            type=type,
            indexed=indexed,
            components=components,
            internalType=internalType,
            _configuration=_configuration,
        )



from .get_token_allowance import get_token_allowance
from .get_token_metadata import get_token_metadata
from .get_token_metadata_by_symbol import get_token_metadata_by_symbol
from .get_token_price import get_token_price
from .get_token_transfers import get_token_transfers
from .get_wallet_token_balances import get_wallet_token_balances
from .get_wallet_token_transfers import get_wallet_token_transfers



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class HistoryModel(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "date",
            "streamId",
            "tinyPayload",
            "errorMessage",
            "id",
            "tag",
            "webhookUrl",
        }
        
        class properties:
        
            @staticmethod
            def id() -> typing.Type['UUID']:
                return UUID
            date = schemas.DateTimeSchema
        
            @staticmethod
            def tinyPayload() -> typing.Type['WebhookTypesITinyPayload']:
                return WebhookTypesITinyPayload
            errorMessage = schemas.StrSchema
            webhookUrl = schemas.StrSchema
            streamId = schemas.StrSchema
            tag = schemas.StrSchema
        
            @staticmethod
            def payload() -> typing.Type['WebhookTypesIWebhookUnParsed']:
                return WebhookTypesIWebhookUnParsed
            __annotations__ = {
                "id": id,
                "date": date,
                "tinyPayload": tinyPayload,
                "errorMessage": errorMessage,
                "webhookUrl": webhookUrl,
                "streamId": streamId,
                "tag": tag,
                "payload": payload,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    date: MetaOapg.properties.date
    streamId: MetaOapg.properties.streamId
    tinyPayload: 'WebhookTypesITinyPayload'
    errorMessage: MetaOapg.properties.errorMessage
    id: 'UUID'
    tag: MetaOapg.properties.tag
    webhookUrl: MetaOapg.properties.webhookUrl
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["date"]) -> MetaOapg.properties.date: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["streamId"]) -> MetaOapg.properties.streamId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tinyPayload"]) -> 'WebhookTypesITinyPayload': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["errorMessage"]) -> MetaOapg.properties.errorMessage: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> 'UUID': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tag"]) -> MetaOapg.properties.tag: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["webhookUrl"]) -> MetaOapg.properties.webhookUrl: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["payload"]) -> 'WebhookTypesIWebhookUnParsed': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["date"], typing_extensions.Literal["streamId"], typing_extensions.Literal["tinyPayload"], typing_extensions.Literal["errorMessage"], typing_extensions.Literal["id"], typing_extensions.Literal["tag"], typing_extensions.Literal["webhookUrl"], typing_extensions.Literal["payload"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["date"]) -> MetaOapg.properties.date: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["streamId"]) -> MetaOapg.properties.streamId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tinyPayload"]) -> 'WebhookTypesITinyPayload': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["errorMessage"]) -> MetaOapg.properties.errorMessage: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> 'UUID': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tag"]) -> MetaOapg.properties.tag: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["webhookUrl"]) -> MetaOapg.properties.webhookUrl: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["payload"]) -> typing.Union['WebhookTypesIWebhookUnParsed', schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["date"], typing_extensions.Literal["streamId"], typing_extensions.Literal["tinyPayload"], typing_extensions.Literal["errorMessage"], typing_extensions.Literal["id"], typing_extensions.Literal["tag"], typing_extensions.Literal["webhookUrl"], typing_extensions.Literal["payload"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        date: typing.Union[MetaOapg.properties.date, str, datetime, ],
        streamId: typing.Union[MetaOapg.properties.streamId, str, ],
        tinyPayload: 'WebhookTypesITinyPayload',
        errorMessage: typing.Union[MetaOapg.properties.errorMessage, str, ],
        id: 'UUID',
        tag: typing.Union[MetaOapg.properties.tag, str, ],
        webhookUrl: typing.Union[MetaOapg.properties.webhookUrl, str, ],
        payload: typing.Union['WebhookTypesIWebhookUnParsed', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'HistoryModel':
        return super().__new__(
            cls,
            *_args,
            date=date,
            streamId=streamId,
            tinyPayload=tinyPayload,
            errorMessage=errorMessage,
            id=id,
            tag=tag,
            webhookUrl=webhookUrl,
            payload=payload,
            _configuration=_configuration,
        )

from openapi_streams.model.uuid import UUID
from openapi_streams.model.webhook_types_i_tiny_payload import WebhookTypesITinyPayload
from openapi_streams.model.webhook_types_i_webhook_un_parsed import WebhookTypesIWebhookUnParsed



import typing_extensions

from openapi_streams.paths import PathValues
from openapi_streams.apis.paths.history import History
from openapi_streams.apis.paths.history_replay_stream_id_id import HistoryReplayStreamIdId
from openapi_streams.apis.paths.settings import Settings
from openapi_streams.apis.paths.stats import Stats
from openapi_streams.apis.paths.stats_stream_id import StatsStreamId
from openapi_streams.apis.paths.streams_evm import StreamsEvm
from openapi_streams.apis.paths.streams_evm_id import StreamsEvmId
from openapi_streams.apis.paths.streams_evm_id_status import StreamsEvmIdStatus
from openapi_streams.apis.paths.streams_evm_id_address import StreamsEvmIdAddress

PathToApi = typing_extensions.TypedDict(
    'PathToApi',
    {
        PathValues.HISTORY: History,
        PathValues.HISTORY_REPLAY_STREAM_ID_ID: HistoryReplayStreamIdId,
        PathValues.SETTINGS: Settings,
        PathValues.STATS: Stats,
        PathValues.STATS_STREAM_ID: StatsStreamId,
        PathValues.STREAMS_EVM: StreamsEvm,
        PathValues.STREAMS_EVM_ID: StreamsEvmId,
        PathValues.STREAMS_EVM_ID_STATUS: StreamsEvmIdStatus,
        PathValues.STREAMS_EVM_ID_ADDRESS: StreamsEvmIdAddress,
    }
)

path_to_api = PathToApi(
    {
        PathValues.HISTORY: History,
        PathValues.HISTORY_REPLAY_STREAM_ID_ID: HistoryReplayStreamIdId,
        PathValues.SETTINGS: Settings,
        PathValues.STATS: Stats,
        PathValues.STATS_STREAM_ID: StatsStreamId,
        PathValues.STREAMS_EVM: StreamsEvm,
        PathValues.STREAMS_EVM_ID: StreamsEvmId,
        PathValues.STREAMS_EVM_ID_STATUS: StreamsEvmIdStatus,
        PathValues.STREAMS_EVM_ID_ADDRESS: StreamsEvmIdAddress,
    }
)



from .add_address_to_stream import add_address_to_stream
from .create_stream import create_stream
from .delete_address_from_stream import delete_address_from_stream
from .delete_stream import delete_stream
from .get_addresses import get_addresses
from .get_stream import get_stream
from .get_streams import get_streams
from .update_stream import update_stream
from .update_stream_status import update_stream_status



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from openapi_evm_api.paths.erc20_address_transfers import Api

from openapi_evm_api.paths import PathValues

path = PathValues.ERC20_ADDRESS_TRANSFERS


from .version import __version__


def get_common_headers():
    """Get the headers for the requests."""
    return {
        "x-moralis-platform": 'Python SDK',
        "x-moralis-platform-version": __version__,
        "x-moralis-build-target": 'python',
    }




# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class ChainList(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        enum_value_to_name = {
            "eth": "ETH",
            "0x1": "X1",
            "goerli": "GOERLI",
            "0x5": "X5",
            "sepolia": "SEPOLIA",
            "0xaa36a7": "XAA36A7",
            "polygon": "POLYGON",
            "0x89": "X89",
            "mumbai": "MUMBAI",
            "0x13881": "X13881",
            "bsc": "BSC",
            "0x38": "X38",
            "bsc testnet": "BSC_TESTNET",
            "0x61": "X61",
            "avalanche": "AVALANCHE",
            "0xa86a": "XA86A",
            "avalanche testnet": "AVALANCHE_TESTNET",
            "0xa869": "XA869",
            "fantom": "FANTOM",
            "0xfa": "XFA",
            "palm": "PALM",
            "0x2a15c308d": "X2A15C308D",
            "cronos": "CRONOS",
            "0x19": "X19",
            "cronos testnet": "CRONOS_TESTNET",
            "0x152": "X152",
            "arbitrum": "ARBITRUM",
            "0xa4b1": "XA4B1",
        }
    
    @schemas.classproperty
    def ETH(cls):
        return cls("eth")
    
    @schemas.classproperty
    def X1(cls):
        return cls("0x1")
    
    @schemas.classproperty
    def GOERLI(cls):
        return cls("goerli")
    
    @schemas.classproperty
    def X5(cls):
        return cls("0x5")
    
    @schemas.classproperty
    def SEPOLIA(cls):
        return cls("sepolia")
    
    @schemas.classproperty
    def XAA36A7(cls):
        return cls("0xaa36a7")
    
    @schemas.classproperty
    def POLYGON(cls):
        return cls("polygon")
    
    @schemas.classproperty
    def X89(cls):
        return cls("0x89")
    
    @schemas.classproperty
    def MUMBAI(cls):
        return cls("mumbai")
    
    @schemas.classproperty
    def X13881(cls):
        return cls("0x13881")
    
    @schemas.classproperty
    def BSC(cls):
        return cls("bsc")
    
    @schemas.classproperty
    def X38(cls):
        return cls("0x38")
    
    @schemas.classproperty
    def BSC_TESTNET(cls):
        return cls("bsc testnet")
    
    @schemas.classproperty
    def X61(cls):
        return cls("0x61")
    
    @schemas.classproperty
    def AVALANCHE(cls):
        return cls("avalanche")
    
    @schemas.classproperty
    def XA86A(cls):
        return cls("0xa86a")
    
    @schemas.classproperty
    def AVALANCHE_TESTNET(cls):
        return cls("avalanche testnet")
    
    @schemas.classproperty
    def XA869(cls):
        return cls("0xa869")
    
    @schemas.classproperty
    def FANTOM(cls):
        return cls("fantom")
    
    @schemas.classproperty
    def XFA(cls):
        return cls("0xfa")
    
    @schemas.classproperty
    def PALM(cls):
        return cls("palm")
    
    @schemas.classproperty
    def X2A15C308D(cls):
        return cls("0x2a15c308d")
    
    @schemas.classproperty
    def CRONOS(cls):
        return cls("cronos")
    
    @schemas.classproperty
    def X19(cls):
        return cls("0x19")
    
    @schemas.classproperty
    def CRONOS_TESTNET(cls):
        return cls("cronos testnet")
    
    @schemas.classproperty
    def X152(cls):
        return cls("0x152")
    
    @schemas.classproperty
    def ARBITRUM(cls):
        return cls("arbitrum")
    
    @schemas.classproperty
    def XA4B1(cls):
        return cls("0xa4b1")



import typing_extensions

from openapi_sol_api.paths import PathValues
from openapi_sol_api.apis.paths.account_network_address_balance import AccountNetworkAddressBalance
from openapi_sol_api.apis.paths.account_network_address_tokens import AccountNetworkAddressTokens
from openapi_sol_api.apis.paths.account_network_address_nft import AccountNetworkAddressNft
from openapi_sol_api.apis.paths.account_network_address_portfolio import AccountNetworkAddressPortfolio
from openapi_sol_api.apis.paths.nft_network_address_metadata import NftNetworkAddressMetadata
from openapi_sol_api.apis.paths.token_network_address_price import TokenNetworkAddressPrice

PathToApi = typing_extensions.TypedDict(
    'PathToApi',
    {
        PathValues.ACCOUNT_NETWORK_ADDRESS_BALANCE: AccountNetworkAddressBalance,
        PathValues.ACCOUNT_NETWORK_ADDRESS_TOKENS: AccountNetworkAddressTokens,
        PathValues.ACCOUNT_NETWORK_ADDRESS_NFT: AccountNetworkAddressNft,
        PathValues.ACCOUNT_NETWORK_ADDRESS_PORTFOLIO: AccountNetworkAddressPortfolio,
        PathValues.NFT_NETWORK_ADDRESS_METADATA: NftNetworkAddressMetadata,
        PathValues.TOKEN_NETWORK_ADDRESS_PRICE: TokenNetworkAddressPrice,
    }
)

path_to_api = PathToApi(
    {
        PathValues.ACCOUNT_NETWORK_ADDRESS_BALANCE: AccountNetworkAddressBalance,
        PathValues.ACCOUNT_NETWORK_ADDRESS_TOKENS: AccountNetworkAddressTokens,
        PathValues.ACCOUNT_NETWORK_ADDRESS_NFT: AccountNetworkAddressNft,
        PathValues.ACCOUNT_NETWORK_ADDRESS_PORTFOLIO: AccountNetworkAddressPortfolio,
        PathValues.NFT_NETWORK_ADDRESS_METADATA: NftNetworkAddressMetadata,
        PathValues.TOKEN_NETWORK_ADDRESS_PRICE: TokenNetworkAddressPrice,
    }
)



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class NormalizedMetadataAttribute(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            trait_type = schemas.StrSchema
            value = schemas.DictSchema
            display_type = schemas.StrSchema
            max_value = schemas.NumberSchema
            trait_count = schemas.NumberSchema
            order = schemas.NumberSchema
            __annotations__ = {
                "trait_type": trait_type,
                "value": value,
                "display_type": display_type,
                "max_value": max_value,
                "trait_count": trait_count,
                "order": order,
            }

    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["trait_type"]) -> MetaOapg.properties.trait_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["display_type"]) -> MetaOapg.properties.display_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["max_value"]) -> MetaOapg.properties.max_value: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["trait_count"]) -> MetaOapg.properties.trait_count: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["order"]) -> MetaOapg.properties.order: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["trait_type", "value", "display_type", "max_value", "trait_count", "order", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["trait_type"]) -> typing.Union[MetaOapg.properties.trait_type, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["value"]) -> typing.Union[MetaOapg.properties.value, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["display_type"]) -> typing.Union[MetaOapg.properties.display_type, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["max_value"]) -> typing.Union[MetaOapg.properties.max_value, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["trait_count"]) -> typing.Union[MetaOapg.properties.trait_count, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["order"]) -> typing.Union[MetaOapg.properties.order, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["trait_type", "value", "display_type", "max_value", "trait_count", "order", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        trait_type: typing.Union[MetaOapg.properties.trait_type, str, schemas.Unset] = schemas.unset,
        value: typing.Union[MetaOapg.properties.value, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        display_type: typing.Union[MetaOapg.properties.display_type, str, schemas.Unset] = schemas.unset,
        max_value: typing.Union[MetaOapg.properties.max_value, decimal.Decimal, int, float, schemas.Unset] = schemas.unset,
        trait_count: typing.Union[MetaOapg.properties.trait_count, decimal.Decimal, int, float, schemas.Unset] = schemas.unset,
        order: typing.Union[MetaOapg.properties.order, decimal.Decimal, int, float, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'NormalizedMetadataAttribute':
        return super().__new__(
            cls,
            *_args,
            trait_type=trait_type,
            value=value,
            display_type=display_type,
            max_value=max_value,
            trait_count=trait_count,
            order=order,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class AdvancedOptions(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Advanced Options for each specific topic
    """


    class MetaOapg:
        required = {
            "topic0",
        }
        
        class properties:
            topic0 = schemas.StrSchema
        
            @staticmethod
            def filter() -> typing.Type['StreamsFilter']:
                return StreamsFilter
            includeNativeTxs = schemas.BoolSchema
            __annotations__ = {
                "topic0": topic0,
                "filter": filter,
                "includeNativeTxs": includeNativeTxs,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    topic0: MetaOapg.properties.topic0
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["topic0"]) -> MetaOapg.properties.topic0: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["filter"]) -> 'StreamsFilter': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["includeNativeTxs"]) -> MetaOapg.properties.includeNativeTxs: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["topic0"], typing_extensions.Literal["filter"], typing_extensions.Literal["includeNativeTxs"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["topic0"]) -> MetaOapg.properties.topic0: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["filter"]) -> typing.Union['StreamsFilter', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["includeNativeTxs"]) -> typing.Union[MetaOapg.properties.includeNativeTxs, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["topic0"], typing_extensions.Literal["filter"], typing_extensions.Literal["includeNativeTxs"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        topic0: typing.Union[MetaOapg.properties.topic0, str, ],
        filter: typing.Union['StreamsFilter', schemas.Unset] = schemas.unset,
        includeNativeTxs: typing.Union[MetaOapg.properties.includeNativeTxs, bool, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'AdvancedOptions':
        return super().__new__(
            cls,
            *_args,
            topic0=topic0,
            filter=filter,
            includeNativeTxs=includeNativeTxs,
            _configuration=_configuration,
        )

from openapi_streams.model.streams_filter import StreamsFilter



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class StreamsTypesStreamsResponse(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "result",
            "total",
        }
        
        class properties:
            
            
            class result(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['StreamsModel']:
                        return StreamsModel
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['StreamsModel'], typing.List['StreamsModel']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'result':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'StreamsModel':
                    return super().__getitem__(i)
            total = schemas.Float64Schema
            cursor = schemas.StrSchema
            __annotations__ = {
                "result": result,
                "total": total,
                "cursor": cursor,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    result: MetaOapg.properties.result
    total: MetaOapg.properties.total
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["result"]) -> MetaOapg.properties.result: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["total"]) -> MetaOapg.properties.total: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["cursor"]) -> MetaOapg.properties.cursor: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["result"], typing_extensions.Literal["total"], typing_extensions.Literal["cursor"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["result"]) -> MetaOapg.properties.result: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["total"]) -> MetaOapg.properties.total: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["cursor"]) -> typing.Union[MetaOapg.properties.cursor, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["result"], typing_extensions.Literal["total"], typing_extensions.Literal["cursor"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        result: typing.Union[MetaOapg.properties.result, list, tuple, ],
        total: typing.Union[MetaOapg.properties.total, decimal.Decimal, int, float, ],
        cursor: typing.Union[MetaOapg.properties.cursor, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'StreamsTypesStreamsResponse':
        return super().__new__(
            cls,
            *_args,
            result=result,
            total=total,
            cursor=cursor,
            _configuration=_configuration,
        )

from openapi_streams.model.streams_model import StreamsModel
